Learn R Programming

miebl (version 0.1.0)

miebl_re: Creates a report for a specific performance criterion from a miebl output

Description

Creates a report for a specific performance criterion from a miebl output

Usage

miebl_re(mb, X = nrow(mb) - 1, mc = 100)

Value

a report on the performance criterion selected with respect to the true mastery level desired

Arguments

mb

object produced by miebl

X

Number of correct responses for the performance criterion

mc

performance criterion expressed as percent e.g. 90% performance criterion is 90

Examples

Run this code
#create a miebl output for default 90% desired true mastery
xx<-miebl(10)
#Uses the miebl output for miebl_re for 90% performance criterion
miebl_re(xx,mc=90)

Run the code above in your browser using DataLab