powered by
Creates a report for a specific performance criterion from a miebl output
miebl_re(mb, X = nrow(mb) - 1, mc = 100)
a report on the performance criterion selected with respect to the true mastery level desired
object produced by miebl
Number of correct responses for the performance criterion
performance criterion expressed as percent e.g. 90% performance criterion is 90
#create a miebl output for default 90% desired true mastery xx<-miebl(10) #Uses the miebl output for miebl_re for 90% performance criterion miebl_re(xx,mc=90)
Run the code above in your browser using DataLab